import django
from configglue.pyschema import ConfigSection
from configglue.pyschema.options import (BoolConfigOption, DictConfigOption,
    IntConfigOption, LinesConfigOption, StringConfigOption)
from django_configglue.schema import schemas


DjangoSchema = schemas.get(django.get_version())


class RnRSchema(DjangoSchema):
    # default
    pgconnect_timeout = IntConfigOption(default=10)
    serve_static_media = BoolConfigOption()
    extra_pythonpath = LinesConfigOption(item=StringConfigOption())
    default_timeout = IntConfigOption(default=None)

    # openid
    openid = ConfigSection()
    openid.openid_create_users = BoolConfigOption()
    openid.openid_reuse_users = BoolConfigOption()
    openid.openid_launchpad_teams_mapping = DictConfigOption()
    openid.openid_sso_server_url = StringConfigOption()
    openid.openid_set_language_from_sreg = BoolConfigOption()
    openid.openid_update_details_from_sreg = BoolConfigOption()

    # logging
    logging = ConfigSection()
    logging.oops_dir = StringConfigOption(help='Absolute path to the'
        'directory oops reports will be stored in')
    logging.logging_config_file = StringConfigOption(fatal=True)

    # loadtest
    loadtest = ConfigSection()
    loadtest.enable_statistics_logging = BoolConfigOption()
    loadtest.network_interfaces = LinesConfigOption(item=StringConfigOption())
    loadtest.disks = LinesConfigOption(item=StringConfigOption())
    loadtest.seconds_between_logging = IntConfigOption(default=5)
    loadtest.stats_to_log = LinesConfigOption(item=StringConfigOption())

    # SSO API
    sso_api = ConfigSection()
    sso_api.sso_api_service_root = StringConfigOption()
    sso_api.sso_api_auth_username = StringConfigOption()
    sso_api.sso_api_auth_password = StringConfigOption()
    sso_api.sso_api_identity_prefix = StringConfigOption()
    sso_api.sso_auth_mode_no_ubuntu_sso_plaintext_only = BoolConfigOption()

    # RnR
    rnr = ConfigSection()
    rnr.moderators_group = StringConfigOption()
    rnr.preload_api_service_roots = BoolConfigOption()
    rnr.api_reviews_pagination = IntConfigOption()
    rnr.cache_review_stats_seconds = IntConfigOption()
    rnr.token_cache_expiry_hours = IntConfigOption(default=4)
    rnr.reviewsapp_media_root = StringConfigOption()
    rnr.force_https_in_environment = BoolConfigOption()
    rnr.allow_multiple_reviews_for_testing = BoolConfigOption(default=False)
    rnr.enable_artificial_oops = BoolConfigOption()

    # Launchpad
    launchpad = ConfigSection()
    launchpad.lp_service = StringConfigOption()
    launchpad.lp_consumer_name = StringConfigOption()
    launchpad.launchpadlib_dir = StringConfigOption(
        default='/tmp/.launchpadlib')

    # Piston
    piston = ConfigSection()
    piston.oauth_data_store = StringConfigOption()

    # Softwarecenter agent.
    sca = ConfigSection()
    sca.sca_host_url = StringConfigOption(
        default='https://software-center.ubuntu.com/')
    sca.sca_apps_cache_timeout = IntConfigOption(default=3600)

    # preflight
    preflight = ConfigSection()
    preflight.preflight_base_template = StringConfigOption(
        default="light/index.1col.html")
