import logging.config
import os
import platform
import sys

from django.conf import settings

# add path to settings to system path if not already there
# check if path is already there to avoid path duplication when
# modwsgi is configured for code reloading
curdir = os.path.abspath(os.path.dirname(__file__))
if curdir not in sys.path:
    sys.path.append(curdir)

os.environ['DJANGO_SETTINGS_MODULE'] = 'settings'

# add extra paths to system path if not already there
# check if path is already there to avoid path duplication when
# modwsgi is configured for code reloading
extra_paths = [path for path in settings.EXTRA_PYTHONPATH \
               if path not in sys.path]
sys.path.extend(extra_paths)

os.environ['PGCONNECT_TIMEOUT'] = str(settings.PGCONNECT_TIMEOUT)

default_id = ''.join(x for x in platform.node() if x.isalpha())
appserver_id = getattr(settings, 'APPSERVER_ID', default_id)

logging.config.fileConfig(os.path.join(curdir, settings.LOGGING_CONFIG_FILE))

from reviewsapp.wsgi import make_app
app = make_app()

def application(environ, start_response):
    # Patch environment if we should be serving https
    if getattr(settings, 'FORCE_HTTPS_IN_ENVIRONMENT'):
        environ['HTTPS'] = 'on'
        environ['wsgi.url_scheme'] = 'https'

    return app(environ, start_response)

