#   -*- coding: utf-8 -*-
#   This file is part of Software Center Ratings and Reviews
#   Copyright (C) 2010-2011 Canonical Ltd.
#
#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU Affero General Public License as
#   published by the Free Software Foundation, either version 3 of the
#   License, or (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU Affero General Public License for more details.
#
#   You should have received a copy of the GNU Affero General Public License
#   along with this program.  If not, see <http://www.gnu.org/licenses/>.

from __future__ import absolute_import
from __future__ import with_statement

__metaclass__ = type
__all__ = [
    'APITransaction',
    'PublicTransaction',
    'VALID_APPS',
    ]

import os

from piston_mini_client.auth import OAuthAuthorizer

import rnrclient
from rnrclient import RatingsAndReviewsAPI


VALID_APPS = (
    ('blender', 'Blender (windowed)'),
    ('stellarium', 'Stellarium'),
    ('chromium-browser', 'Chromium Web Browser'),
    )


# If an env var has been used to specify the AUTHENTICATED_API_SCHEME,
# then we update the rnrclient to use that (this is used mainly for
# running against dev servers).
if os.environ.has_key('AUTHENTICATED_API_SCHEME'):
    rnrclient.AUTHENTICATED_API_SCHEME = os.environ[
        'AUTHENTICATED_API_SCHEME']


class APITransaction(object):
    """Helper to setup both the public and auth rnr api."""

    def __init__(self):
        self.custom_timers = {}

        host = os.environ['LOAD_TEST_HOST']

        self.public_rnr_client = RatingsAndReviewsAPI(
            'http://{0}/reviews/api/1.0'.format(host))

        # For the authorized load testing to work on the host, you will
        # first need to create the credentials.
        auth = OAuthAuthorizer('load_token_string', 'load_token_secret',
            'load_tester', 'load_consumer_secret')
        self.auth_rnr_client = RatingsAndReviewsAPI(
            'https://{0}/reviews/api/1.0'.format(host), auth=auth)
