#   -*- coding: utf-8 -*-
#   This file is part of Software Center Ratings and Reviews
#   Copyright (C) 2010-2011 Canonical Ltd.
#
#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU Affero General Public License as
#   published by the Free Software Foundation, either version 3 of the
#   License, or (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU Affero General Public License for more details.
#
#   You should have received a copy of the GNU Affero General Public License
#   along with this program.  If not, see <http://www.gnu.org/licenses/>.

from __future__ import absolute_import
from __future__ import with_statement

__metaclass__ = type
__all__ = [
    'Transaction',
    ]

import random
import time
import urllib

from load_test_helpers import (
    APITransaction,
    VALID_APPS,
    )


class Transaction(APITransaction):

    def run(self):
        pkgname, appname = VALID_APPS[random.randint(0, len(VALID_APPS) - 1)]

        appname = urllib.quote_plus(appname.encode('utf-8'))

        # We first grab the first page of reviews from the app to get
        # a review.
        reviews = self.public_rnr_client.get_reviews(
            packagename=pkgname, appname=appname, page=1)

        if len(reviews) > 0:
            review = reviews[0]
            start_timer = time.time()
            useful = (random.randint(0, 1) == 1)
            response = self.auth_rnr_client.submit_usefulness(
                review_id=review.id, useful=str(useful))
            latency = time.time() - start_timer
            self.custom_timers['recommend_review_complete'] = latency

            assert response in ['Created', 'Updated', 'Not modified'], (
                'Unexpected response.')


if __name__ == '__main__':
    trans = Transaction()
    trans.run()
    print trans.custom_timers
