#   -*- coding: utf-8 -*-
#   This file is part of Software Center Ratings and Reviews
#   Copyright (C) 2010-2011 Canonical Ltd.
#
#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU Affero General Public License as
#   published by the Free Software Foundation, either version 3 of the
#   License, or (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU Affero General Public License for more details.
#
#   You should have received a copy of the GNU Affero General Public License
#   along with this program.  If not, see <http://www.gnu.org/licenses/>.
import os
import os.path

from fabric.api import local, cd


def _get_or_pull_bzr_branch(repo, name):
    branch_path = os.path.join("branches", name)
    if os.path.exists(branch_path):
        local("cd {0} && bzr pull".format(branch_path), capture=False)
    else:
        local("bzr branch {0} {1}".format(repo, branch_path), capture=False)


def virtualenv_create():
    local("rm -rf virtualenv/*")
    local("virtualenv --no-site-packages virtualenv", capture=False)


def install_requirements():
    local("virtualenv/bin/pip install -r requirements.txt", capture=False)
    local("virtualenv/bin/python setup.py develop", capture=False)


def pull_required_branches():
    _get_or_pull_bzr_branch(
        "lp:~software-store-developers/piston-mini-client/trunk",
        "piston-mini-client")
    _symlink(
        "branches/piston-mini-client/piston_mini_client",
        "django_project/piston_mini_client")

    _get_or_pull_bzr_branch(
        "lp:~rnr-developers/rnr-server/rnrclient",
        "rnrclient")
    _symlink(
        "branches/rnrclient/rnrclient.py",
        "django_project/rnrclient.py")

    _get_or_pull_bzr_branch(
        "lp:~canonical-isd-hackers/canonical-identity-provider/2.x-trunk",
        "canonical-identity-provider")
    _symlink(
        "branches/canonical-identity-provider/mockservice/sso_mockserver",
        "django_project/mockssoservice")

    _get_or_pull_bzr_branch(
        "lp:wsgi-oops",
        "wsgi-oops")
    _symlink(
        "branches/wsgi-oops/canonical",
        "django_project/canonical")

def download_multi_mechanize():
    multi_mechanize = "multi-mechanize_1.010.zip"
    local("wget http://multi-mechanize.googlecode.com/files/{0}".format(
        multi_mechanize))
    local("unzip {0} -d branches".format(multi_mechanize))
    local("rm {0}".format(multi_mechanize))
    local("mv branches/{0} branches/multi-mechanize".format(
        os.path.splitext(multi_mechanize)[0]))

    _symlink('django_project/load_testing',
             'branches/multi-mechanize/projects/rnr')

def _symlink(source, link_name):
    if not os.path.exists(link_name):
        os.symlink(os.path.abspath(source), link_name)


def bootstrap():
    virtualenv_create()
    install_requirements()
    pull_required_branches()
    download_multi_mechanize()


def clean():
    local("rm -rf branches/*")
    local("rm -rf virtualenv/*")
    local("rm -f django_project/mockssoservice")
    local("rm -f django_project/rnrclient.py")
    local("rm -f django_project/piston_mini_client")
