#   -*- coding: utf-8 -*-
#   This file is part of Software Center Ratings and Reviews
#   Copyright (C) 2010-2011 Canonical Ltd.
#
#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU Affero General Public License as
#   published by the Free Software Foundation, either version 3 of the
#   License, or (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU Affero General Public License for more details.
#
#   You should have received a copy of the GNU Affero General Public License
#   along with this program.  If not, see <http://www.gnu.org/licenses/>.
from glob import glob
from fabric.api import local
from fabric.utils import abort
from ConfigParser import ConfigParser
from xml.etree import ElementTree as et

def manage(command, *args):
    """Run manage.py command"""
    local("virtualenv/bin/python django_project/manage.py {0} {1}".format(
        command, " ".join(args)), capture=False,)


def test(spec=None):
    if spec is None:
        spec = "reviewsapp"
    manage("test", spec)


def runserver(port=8000):
    manage("runserver", str(port))


def syncdb():
    manage("syncdb", "--migrate")


def run(port=8000):
    syncdb()
    runserver(port)


def coverage(branch=False, xml=False):
    cov = lambda args: local("virtualenv/bin/coverage " + args,
                             capture=False)

    local("rm -rf .coverage coverage/ coverage.xml")

    cov("run {0} django_project/manage.py test reviewsapp".format(
        '--branch' if branch else ''))
    cov("combine")
    if xml:
        cov("xml --include='src/*' -o coverage.xml")
    else:
        cov("html -d coverage/ --include='src/*'")


def jenkins():
    # Required for getting results reported in Jenkins
    local("virtualenv/bin/pip -q install unittest-xml-reporting==1.0.2")

    # Make sure that test runner setting is in local.cfg
    local_cfg = ConfigParser()
    local_cfg.read(["django_project/local.cfg"])
    if not local_cfg.has_section('django'):
        local_cfg.add_section('django')
    if not local_cfg.has_option('django', 'test_runner'):
        local_cfg.set('django', 'test_runner',
                      'xmlrunner.extra.djangotestrunner.run_tests')
    local_cfg.write(open("django_project/local.cfg", "w"))

    coverage(branch=True, xml=True)

    failed = False
    # Check if any test have failed
    for result in glob('*.xml'):
        testsuite = et.parse(result).getroot()
        if testsuite.tag != 'testsuite':
            continue
        if testsuite.get('errors') != '0' or testsuite.get('failures') != '0':
            failed = True
            break

    local("sloccount --wide --details src > sloccount.sc")

    # This is only for making sure that the correct status is returned to the
    # CI server, which will cause it to properly mark the build as
    # FAILURE. Without it the build would be only as unstable.
    if failed:
        abort("Test suite failed")
