#   -*- coding: utf-8 -*-
#   This file is part of Software Center Ratings and Reviews
#   Copyright (C) 2010-2011 Canonical Ltd.
#
#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU Affero General Public License as
#   published by the Free Software Foundation, either version 3 of the
#   License, or (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU Affero General Public License for more details.
#
#   You should have received a copy of the GNU Affero General Public License
#   along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Fabric commands for load testing localhost or a server."""

from __future__ import (
    absolute_import,
    with_statement,
    )

__metaclass__ = type
__all__ = [
    'load_test',
    ]

import os
import os.path

from fabric.api import (
    cd,
    local,
    )


def load_test(host, project=None):
    """Run the default project load test against host."""
    # Until there's a way to pass a configurable host to
    # multi-mechanize, we use the python env to communicate the
    # target host for the load test. This is used in the
    # load_testing/test_scripts/* tests.
    os.environ['LOAD_TEST_HOST'] = host
    # We'll default to the assumption that if the host is local, we
    # should use http for authenticated requests.
    hostname, sep, port = host.partition(':')
    if hostname in ('localhost', '127.0.0.1'):
        os.environ['AUTHENTICATED_API_SCHEME'] = 'http'

    path = os.path.abspath('django_project')
    python = os.path.abspath('virtualenv/bin/python')

    # XXX Currently multi-mechanize doesn't allow specifying the
    # project directory, so cd and relative paths to work-around.
    with cd(os.path.join('branches', 'multi-mechanize')):
        local("PYTHONPATH={0} {1} multi-mechanize.py rnr".format(
            path, python), capture=False)
