import os.path
from fabric.api import *
from space.shuttle import *

LOCAL_CONFIG = """
[__noschema__]
basedir = /root/django_project
hostname = %(hostname)s

[__main__]
includes = config/staging.cfg

[django]
database_engine = postgresql_psycopg2
database_host = localhost
database_user = rnr
database_name = rnr

[logging]
logging_config_file = /root/django_project/staging_logging.conf
oops_dir = /root/staging-logs/www-oops/
"""


def install_base():
    install(
        debs = [
            "bzip2",
            "python-httplib2",
            "apache2",
            "squid",
            "libapache2-mod-wsgi",
            "postgresql",
            "canonical-isd-web-dependencies",
            "python-django-piston",
        ],
        bzr = [("lp:~canonical-isd-hackers/isd-configs/rnr-config",
                "django_project"),
              ]
    )
    configure_postgres("rnr", postgresql_version="8.4")

def setup_apache():
    configure_apache(
        name = "ratings-and-reviews",
        wsgi_script = "/root/django_project/django.wsgi",
        static = {
            '/media': '/usr/share/pyshared/django/contrib/admin/media',
        },
        extra=["WSGIPassAuthorization On"],
    )

    # Create oops directory
    create_dir("/root/staging-logs/www-oops",
               sudo=True, owner="www-data:www-data")

    # Create logs directory
    create_dir("/root/staging-logs/www-logs",
               sudo=True, owner="www-data:www-data")

    # Start squid
    run('sudo /etc/init.d/squid restart')

def setup_and_configure_everything():
    setup_apache()
    configure()

def configure():
    #
    # Adjusting settings for ec2 environment
    #
    with create_file('~/django_project/local.cfg') as wsgi_file:
        wsgi_file.write(LOCAL_CONFIG % {'hostname': env.host_string})

    # Create the database
    run("cd ~/django_project && ./manage.py syncdb --noinput")
    run("cd ~/django_project && ./manage.py migrate")
    run("cd ~/django_project && ./manage.py loaddata samples")

    # Add our LP public keys to allow access to the team
    run('ssh-import-lp-id elachuni ricardokirkner lukasz-czyzykowski '
        'dsowen zematynnad michael.nelson mvo')

def deploy():
    try:
        enable_private_ppa(series="lucid", update_apt=True)
        install_base()
    finally:
        disable_private_ppa(update_apt=True)

    setup_and_configure_everything()

def deploy_local(*deb_paths):
    try:
        enable_private_ppa(series="lucid", update_apt=True)
        install_base()
        for deb_path in deb_paths:
            put(deb_path, '/tmp')
            run("sudo dpkg -i /tmp/%s" % os.path.basename(deb_path))
    finally:
        disable_private_ppa(update_apt=True)

    setup_and_configure_everything()

