#   This file is part of Software Center Ratings and Reviews
#   Copyright (C) 2010 Canonical Ltd.
#
#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU Affero General Public License as
#   published by the Free Software Foundation, either version 3 of the
#   License, or (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU Affero General Public License for more details.
#
#   You should have received a copy of the GNU Affero General Public License
#   along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Admininstrative interface setup code."""


from __future__ import absolute_import

__metaclass__ = type

from django.contrib import admin
from django.http import HttpResponse

from reviewsapp.models import (
    Architecture,
    Repository,
    Review,
    ReviewModeration,
    ReviewModerationFlag,
    RNRSettings,
    SoftwareItem,
    )

class RNRSettingsAdmin(admin.ModelAdmin):
    """Ensure that only one instance is ever created"""
    def add_view(self, request):
        if request.method== 'POST':
            if RNRSettings.objects.count() > 0:
                return HttpResponse('Only one RNR Settings object should be '
                                    'created.')
        return super(RNRSettingsAdmin, self).add_view(request)


admin.site.register(Architecture)
admin.site.register(Repository)
admin.site.register(Review)
admin.site.register(SoftwareItem)
admin.site.register(ReviewModeration)
admin.site.register(ReviewModerationFlag)
admin.site.register(RNRSettings, RNRSettingsAdmin)
