
from south.db import db
from django.db import models
from reviewsapp.models import *

class Migration:

    def forwards(self, orm):
        """Copy the app name from the software item and update the link."""
        # For each software_item, we want to update all the related
        # reviews.
        for software_item in orm['reviewsapp.softwareitem'].objects.all():
            software_item.review_set.update(
                app_name=software_item.app_name)

        # Next, we ensure that all the reviews for a given packagename
        # refer to a single software_item, and delete the redundant
        # softawre_items.
        package_names = orm['reviewsapp.softwareitem'].objects.values_list(
            'package_name', flat=True)
        package_names = package_names.order_by('package_name').distinct()
        for package_name in package_names:
            # Grab all the reviews for a given package name and update
            # them to all point to the one software item.
            reviews = orm['reviewsapp.review'].objects.filter(
                softwareitem__package_name=package_name)
            if reviews:
                first_review = reviews[0]
                remaining_software_item = reviews[0].softwareitem
                reviews.update(softwareitem=remaining_software_item)

                # Now delete all the other software items with the same
                # package name (and software item in origins /
                # repositories).
                orm['reviewsapp.softwareitem'].objects.filter(
                    package_name=package_name).exclude(
                        id=remaining_software_item.id).delete()

                # Finally, we need to ensure that each review corresponds
                # to a valid SoftwareItemInRepository so that stats can be
                # calculated.
                self.ensure_softwareitem_in_repos(orm, remaining_software_item)
            else:
                # There were no reviews for the given package name. It's
                # an orphaned software_item, which shouldn't happen on
                # staging/production but our daily server does have these.
                # Anthony is creating an sql query to verify on staging.
                print("Deleting orphaned softwareitems for "
                      "packagesname: %s" % package_name)
                orm['reviewsapp.softwareitem'].objects.filter(
                    package_name=package_name).delete()


    def backwards(self, orm):
        """Create the software items with app names and update reviews."""
        SoftwareItemClass = orm['reviewsapp.softwareitem']
        for software_item in SoftwareItemClass.objects.all():
            app_names = software_item.review_set.values_list(
                'app_name', flat=True).distinct()
            software_item.app_name = app_names[0]
            software_item.save()
            package_name = software_item.package_name
            # We need to recreate the repository/origin stats for
            # the existing softwareitem.
            software_item.softwareiteminrepository_set.all().delete()
            software_item.softwareiteminorigin_set.all().delete()

            # For any other app names, we create a new software item and
            # point the relevant reviews to it.
            for app_name in app_names:
                new_item, created = SoftwareItemClass.objects.get_or_create(
                    package_name=package_name,
                    app_name=app_name)

                orm['reviewsapp.review'].objects.filter(
                    softwareitem=software_item,
                    app_name=app_name).update(
                        softwareitem=new_item)

        # Once all review.software_items have been updated, we can
        # create the related items in repos etc.
        for item in SoftwareItemClass.objects.all():
            self.ensure_softwareitem_in_repos(orm, item)

        # Finally, blank out the Review.app_name field.
        orm['reviewsapp.review'].objects.all().update(app_name='')

    def ensure_softwareitem_in_repos(self, orm, software_item):
        # Find all reviews referencing the item and get a list of
        # distint repositories.
        reviews = orm['reviewsapp.review'].objects.filter(
            softwareitem=software_item)
        repository_ids = reviews.values_list('repository', flat=True).distinct()
        SIIRepo = orm['reviewsapp.softwareiteminrepository']
        SIIOrigin = orm['reviewsapp.softwareiteminorigin']
        for repo_id in repository_ids:
            repo = orm['reviewsapp.repository'].objects.get(id=repo_id)
            item_in_repo, created = SIIRepo.objects.get_or_create(
                softwareitem=software_item, repository=repo)
            item_in_origin, created = SIIOrigin.objects.get_or_create(
                softwareitem=software_item, origin=repo.origin)


    models = {
        'auth.group': {
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '80'}),
            'permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'})
        },
        'auth.permission': {
            'Meta': {'unique_together': "(('content_type', 'codename'),)"},
            'codename': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
        },
        'auth.user': {
            'date_joined': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75', 'blank': 'True'}),
            'first_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'groups': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Group']", 'symmetrical': 'False', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_active': ('django.db.models.fields.BooleanField', [], {'default': 'True', 'blank': 'True'}),
            'is_staff': ('django.db.models.fields.BooleanField', [], {'default': 'False', 'blank': 'True'}),
            'is_superuser': ('django.db.models.fields.BooleanField', [], {'default': 'False', 'blank': 'True'}),
            'last_login': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'last_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'password': ('django.db.models.fields.CharField', [], {'max_length': '128'}),
            'user_permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'}),
            'username': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '30'})
        },
        'contenttypes.contenttype': {
            'Meta': {'unique_together': "(('app_label', 'model'),)", 'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        'reviewsapp.architecture': {
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'tag': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '16'})
        },
        'reviewsapp.consumer': {
            'created_at': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'key': ('django.db.models.fields.CharField', [], {'max_length': '64'}),
            'secret': ('django.db.models.fields.CharField', [], {'default': "'qBxqBnulneXJvOyccXpAJdJmhzatIw'", 'max_length': '255', 'blank': 'True'}),
            'updated_at': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'blank': 'True'}),
            'user': ('django.db.models.fields.related.OneToOneField', [], {'related_name': "'oauth_consumer'", 'unique': 'True', 'to': "orm['auth.User']"})
        },
        'reviewsapp.nonce': {
            'consumer': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['reviewsapp.Consumer']"}),
            'created_at': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'nonce': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '255'}),
            'token': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['reviewsapp.Token']"})
        },
        'reviewsapp.repository': {
            'distroseries': ('django.db.models.fields.SlugField', [], {'max_length': '25', 'db_index': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'origin': ('django.db.models.fields.SlugField', [], {'max_length': '100', 'db_index': 'True'})
        },
        'reviewsapp.review': {
            'app_name': ('django.db.models.fields.CharField', [], {'default': "''", 'max_length': '100', 'blank': 'True'}),
            'architecture': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['reviewsapp.Architecture']"}),
            'date_created': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime(2011, 3, 18, 11, 13, 11, 823749)'}),
            'hide': ('django.db.models.fields.BooleanField', [], {'default': 'False', 'db_index': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'language': ('django.db.models.fields.SlugField', [], {'max_length': '10', 'db_index': 'True'}),
            'rating': ('django.db.models.fields.IntegerField', [], {}),
            'repository': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['reviewsapp.Repository']"}),
            'review_text': ('django.db.models.fields.CharField', [], {'max_length': '5000'}),
            'reviewer': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['auth.User']"}),
            'softwareitem': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['reviewsapp.SoftwareItem']"}),
            'summary': ('django.db.models.fields.CharField', [], {'max_length': '80'}),
            'usefulness_favorable': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'usefulness_percentage': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'usefulness_total': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'version': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        'reviewsapp.reviewmoderation': {
            'date_created': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime(2011, 3, 18, 11, 13, 11, 959691)'}),
            'date_moderated': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'moderation_text': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'moderator': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['auth.User']", 'null': 'True', 'blank': 'True'}),
            'review': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['reviewsapp.Review']"}),
            'status': ('django.db.models.fields.SmallIntegerField', [], {'default': '0'})
        },
        'reviewsapp.reviewmoderationflag': {
            'date_created': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime(2011, 3, 18, 11, 13, 12, 530560)'}),
            'description': ('django.db.models.fields.TextField', [], {}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'review_moderation': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['reviewsapp.ReviewModeration']"}),
            'summary': ('django.db.models.fields.CharField', [], {'max_length': '200'}),
            'user': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['auth.User']", 'null': 'True'})
        },
        'reviewsapp.rnrsettings': {
            'blacklist_words': ('django.db.models.fields.TextField', [], {'default': "''"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'moderation_mode': ('django.db.models.fields.CharField', [], {'default': "'passive'", 'max_length': '8'})
        },
        'reviewsapp.softwareitem': {
                'app_name': ('django.db.models.fields.CharField', [], {'max_length': '100', 'blank': 'True', 'default': "''"}),
            'date_ratings_updated': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime(2011, 3, 18, 11, 13, 11, 529267)'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'package_name': ('django.db.models.fields.SlugField', [], {'max_length': '100', 'db_index': 'True'}),
            'ratings_average': ('django.db.models.fields.DecimalField', [], {'default': '0', 'max_digits': '3', 'decimal_places': '2'}),
            'ratings_total': ('django.db.models.fields.IntegerField', [], {'default': '0'})
        },
        'reviewsapp.softwareiteminorigin': {
            'Meta': {'unique_together': "(('softwareitem', 'origin'),)"},
            'date_ratings_updated': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime(2011, 3, 18, 11, 13, 11, 529267)'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'origin': ('django.db.models.fields.SlugField', [], {'max_length': '100', 'db_index': 'True'}),
            'ratings_average': ('django.db.models.fields.DecimalField', [], {'default': '0', 'max_digits': '3', 'decimal_places': '2'}),
            'ratings_total': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'softwareitem': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['reviewsapp.SoftwareItem']"})
        },
        'reviewsapp.softwareiteminrepository': {
            'Meta': {'unique_together': "(('softwareitem', 'repository'),)"},
            'date_ratings_updated': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime(2011, 3, 18, 11, 13, 11, 529267)'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'ratings_average': ('django.db.models.fields.DecimalField', [], {'default': '0', 'max_digits': '3', 'decimal_places': '2'}),
            'ratings_total': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'repository': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['reviewsapp.Repository']"}),
            'softwareitem': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['reviewsapp.SoftwareItem']"})
        },
        'reviewsapp.token': {
            'consumer': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['reviewsapp.Consumer']"}),
            'created_at': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '255', 'blank': 'True'}),
            'token': ('django.db.models.fields.CharField', [], {'default': "'mwoIqDbtCeQyFKvSAnleoBTvXpZzbKjDdkxAmBxsqpuAftkRvt'", 'max_length': '50', 'primary_key': 'True'}),
            'token_secret': ('django.db.models.fields.CharField', [], {'default': "'wTeEOEKkKzbDsJPtEUszuDgiDToSnKlTZjnOIrDlWXYKNkDkSr'", 'max_length': '50'}),
            'updated_at': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'blank': 'True'})
        },
        'reviewsapp.usefulness': {
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'review': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['reviewsapp.Review']"}),
            'useful': ('django.db.models.fields.BooleanField', [], {'default': 'False', 'db_index': 'True', 'blank': 'True'}),
            'user': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['auth.User']"})
        }
    }

    complete_apps = ['reviewsapp']
