#   -*- coding: utf-8 -*-
#   This file is part of Software Center Ratings and Reviews
#   Copyright (C) 2010-2011 Canonical Ltd.
#
#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU Affero General Public License as
#   published by the Free Software Foundation, either version 3 of the
#   License, or (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU Affero General Public License for more details.
#
#   You should have received a copy of the GNU Affero General Public License
#   along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Django-preflight checks."""

from __future__ import absolute_import

__metaclass__ = type
__all__ = []

import launchpadlib
import openid
import piston.utils
import south
from django.conf import settings
from preflight import Preflight, register

import reviewsapp
from .utilities import WebServices


class RNRPreflight(Preflight):

    versions = [
        {'name': 'rnr-server', 'version': reviewsapp.__version__},
        {'name': 'openid', 'version': openid.__version__},
        {'name': 'launchpadlib', 'version': launchpadlib.__version__},
        {'name': 'piston', 'version': piston.utils.__version__},
        {'name': 'South', 'version': south.__version__},
    ]

    def authenticate(self, request):
        return (request.user.is_authenticated() and
                bool(request.user.groups.filter(name='rnr-developers')))

    def check_identity_provider_api_access(self):
        """
        Make sure that the access to the Ubuntu SSO API is correct.

        """
        sso = WebServices().identity_provider
        # Getting list of tokens for wrong customer should result with an
        # empty list. If anything goes wrong then api will raise an
        # exception (like: HTTP Error 401: Unauthorized)
        tokens = sso.authentications.list_tokens(
            consumer_key='wrong-consumer-key')
        return len(tokens) == 0

    def check_launchpad_api_access(self):
        """
        Make sure that the access to the Launchpad API (anonymous) works.

        """
        # Pull one data item from Launchpad
        bug = WebServices().launchpad_service.bugs[1]
        return bug.id == 1

    def check_validate_config(self):
        """
        Make sure that our config files validate correctly.
        """
        parser = settings.__CONFIGGLUE_PARSER__
        return parser.is_valid()

    def check_sca_validation(self):
        pubs = WebServices().get_sca_publishings_for('maverick', 'i386')
        return type(pubs) == dict


register(RNRPreflight)
