#   This file is part of Software Center Ratings and Reviews
#   Copyright (C) 2010-2011 Canonical Ltd.
#
#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU Affero General Public License as
#   published by the Free Software Foundation, either version 3 of the
#   License, or (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU Affero General Public License for more details.
#
#   You should have received a copy of the GNU Affero General Public License
#   along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Custom template filters and tags used by the reviews app."""

from __future__ import absolute_import

__metaclass__ = type
__all__ = [
    'can_moderate_item',
    'date_with_timesince',
    'lp_user',
    ]

from django import template
from django.utils.html import conditional_escape
from django.utils.safestring import mark_safe
from django.utils.translation import ugettext_lazy as _
from django.utils.timesince import timesince


register = template.Library()

@register.filter
def lp_user(user, autoescape=None):
    if user is None:
        return ''
    name = user.get_full_name()

    # Only escape the user names if autoescape is True.
    if autoescape:
        escape = conditional_escape
    else:
        escape = lambda x: x

    if name == "":
        name = user.username

    result = u'<a href="https://launchpad.net/~{0}">{1}</a>'.format(
        escape(user.username), escape(name))
    return mark_safe(result)
lp_user.needs_autoescape = True

@register.filter
def date_with_timesince(date):
    return (
        date.strftime("%Y-%m-%d %H:%M") + " - " +_("{timesince} ago").format(
            timesince=timesince(date)))

@register.filter
def can_moderate_item(review_moderation, user):
    return review_moderation.can_be_moderated_by(user)

