#   This file is part of Software Center Ratings and Reviews
#   Copyright (C) 2010 Canonical Ltd.
#
#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU Affero General Public License as
#   published by the Free Software Foundation, either version 3 of the
#   License, or (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU Affero General Public License for more details.
#
#   You should have received a copy of the GNU Affero General Public License
#   along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Ubuntu App Review test helpers."""

from __future__ import absolute_import

__metaclass__ = type
__all__ = [
    'WSGIInterceptedTestCase',
    'mock_data_for_account',
    ]

from contextlib import contextmanager
from unittest import TestCase

from django.conf import settings
from wsgi_intercept import add_wsgi_intercept, remove_wsgi_intercept
from wsgi_intercept.httplib2_intercept import install, uninstall


class WSGIInterceptedTestCase(TestCase):
    def setUp(self, callbacks):
        super(WSGIInterceptedTestCase, self).setUp()
        self.intercepted = []
        install()

        for key, callback in callbacks.items():
            if key == 'default':
                continue
            host, port = key
            add_wsgi_intercept(host, port, callback)
            self.intercepted.append((host, port))

    def tearDown(self):
        for host, port in self.intercepted:
            remove_wsgi_intercept(host, port)
        uninstall()
        super(WSGIInterceptedTestCase, self).tearDown()


# Original snippet from http://djangosnippets.org/snippets/2156/
class SettingDoesNotExist:
    pass


def switch_settings(**kwargs):
    """Helper method that updates settings and returns old settings."""
    old_settings = {}
    for key, new_value in kwargs.items():
        old_value = getattr(settings, key, SettingDoesNotExist)
        old_settings[key] = old_value

        if new_value is SettingDoesNotExist:
            delattr(settings, key)
        else:
            setattr(settings, key, new_value)

    return old_settings

@contextmanager
def patch_settings(**kwargs):
    old_settings = switch_settings(**kwargs)
    yield
    switch_settings(**old_settings)
# end snippet


def mock_data_for_account(consumer, token, **kwargs):
    """ A credible return value for get_data_for_account. """
    data = {
            'preferred_email': 'foo@bar.com',
            'username': 'foobar',
            'displayname': 'foo bar',
            'consumer_secret': consumer.secret,
            'token': token.token,
            'token_secret': token.token_secret,
            'name': token.name,
        }
    data.update(kwargs)
    return data
