#   This file is part of Software Center Ratings and Reviews
#   Copyright (C) 2010 Canonical Ltd.
#
#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU Affero General Public License as
#   published by the Free Software Foundation, either version 3 of the
#   License, or (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU Affero General Public License for more details.
#
#   You should have received a copy of the GNU Affero General Public License
#   along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Unittest matchers used to simplify tests."""

from __future__ import absolute_import

__metaclass__ = type
__all__ = [
    'ContainsStatsForPackage',
    ]

from decimal import Decimal

from testtools.matchers import (
    Matcher,
    Mismatch,
    )


class ContainsStatsForPackage(Matcher):
    """Checks whether a list contains a statistics for a package."""

    def __init__(self, package_name, average, count=1):
        """Create an ContainsStatsForPackage matcher.

        :param package_name: the name of the package for which the stats
            should be present.
        :param average: The expected average for the package stats.
        :param count: The expected number of reviews for the package stats.
        """
        self.package_name = package_name
        self.count = count
        self.average = Decimal(average)

    def __str__(self):
        return "Contains the raw statistics for a package."

    def match(self, matchee):
        num_matched = 0
        expected = {
            'package_name': self.package_name,
            # XXX 2011-03-18 michaeln bug=737649
            # We include a blank app_name until the USC client no longer
            # expects the app_name attribute in the stats.
            'app_name': '',
            'ratings_total': self.count,
            'ratings_average': self.average,
            }
        for package in matchee:
            package['ratings_average'] = Decimal(package['ratings_average'])
            if package == expected:
                num_matched += 1

        if num_matched == 1:
            return None

        return Mismatch(
            "There was {0} stats matching {1}.".format(
                num_matched, expected))
