#   -*- coding: utf-8 -*-
#   This file is part of Software Center Ratings and Reviews
#   Copyright (C) 2010-2011 Canonical Ltd.
#
#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU Affero General Public License as
#   published by the Free Software Foundation, either version 3 of the
#   License, or (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU Affero General Public License for more details.
#
#   You should have received a copy of the GNU Affero General Public License
#   along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Tests for the preflight integration."""

from __future__ import (
    absolute_import,
    with_statement,
    )

__metaclass__ = type
__all__ = [
    'TestPreflight',
    ]

from mock import patch

from django.contrib.auth.models import User, Group

from reviewsapp.tests.factory import TestCaseWithFactory


class TestPreflight(TestCaseWithFactory):

    def _request_preflight(self, authenticated=True, user=None):
        if authenticated:
            if user is None:
                user = self.factory.makeUser()
                group =  Group.objects.get(name='rnr-developers')
                user.groups.add(group)
            login = self.client.login(username=user.username, password='test')
            self.assertTrue(login, 'Could not log in')

        with patch('preflight.models.gather_checks') as mock_gather_checks:
            mock_gather_checks.return_value = []
            response = self.client.get('/preflight/')
        return response

    def test_anonymous(self):
        response = self._request_preflight(authenticated=False)

        self.assertEqual(404, response.status_code)

    def test_logged_in_no_group(self):
        user = self.factory.makeUser(username='test')

        response = self._request_preflight(user=user)

        self.assertEqual(404, response.status_code)

    def test_logged_in_wrong_group(self):
        g = Group.objects.create(name='someothergroup')
        user = self.factory.makeUser(username='test')
        user.groups.add(g)

        response = self._request_preflight(user=user)

        self.assertEqual(404, response.status_code)

    def test_success(self):
        response = self._request_preflight()

        self.assertEqual(200, response.status_code)
        libs = set([x['name'] for x in response.context[0]['versions']])
        expected = set([
            'rnr-server', 'openid', 'Python', 'Django', 'piston',
            'launchpadlib', 'South', 'preflight',
        ])
        self.assertEqual(expected, libs)
