#   This file is part of Software Center Ratings and Reviews
#   Copyright (C) 2010 Canonical Ltd.
#
#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU Affero General Public License as
#   published by the Free Software Foundation, either version 3 of the
#   License, or (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU Affero General Public License for more details.
#
#   You should have received a copy of the GNU Affero General Public License
#   along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""URL to view mappings"""

from __future__ import absolute_import

__metaclass__ = type
__all__ = [
    'urlpatterns',
    ]


from django.conf import settings
from django.conf.urls.defaults import (
    patterns,
    include,
    url,
    )
from django.views.decorators.cache import never_cache

from reviewsapp.views import overview, moderation


urlpatterns = patterns('reviewsapp.views',
    # Overview of the reviews application.
    url(r'^$', overview, name='rnr-overview'),

    # ReviewModeration list filtered by status, distroseries or language.
    url(r'moderations/$', never_cache(moderation.reviewmoderation_list),
        name='rnr-reviewmoderation-list'),

    url(r'moderations/(?P<moderation_id>\d+)/$',
        never_cache(moderation.reviewmoderation_detail),
        name='rnr-reviewmoderation-detail'),

    url(r'moderations/(?P<moderation_id>\d+)/moderate/$',
        never_cache(moderation.reviewmoderation_moderate),
        name='rnr-reviewmoderation-moderate'),

    # Display a message saying that the current user doesn't have access to
    # the moderation screens.
    (r'^forbidden', never_cache(moderation.forbidden)),

    # Include the API urls
    (r'^api/', include('reviewsapp.api.urls')),
)

if getattr(settings, 'ENABLE_ARTIFICIAL_OOPS', False):
    urlpatterns += patterns('reviewsapp.views',
        (r'^die/', 'die'),
    )
